# RSB

## A RAM saving cli to run web applications

### Note : It is my first cli, so please inform me if something is wrong

PS: I am aware of some bugs but I will fix them after my exams

## How to install

Note: My exams are starting so I am going to continue working on this after my exams

### Linux/Mac

#### For Debian based OS-

If you don't have python or pip installed

cd ~/Downloads;wget https://raw.githubusercontent.com/AvanindraC/RSB/blob/main/install.sh; sudo bash install.sh

If you have python installed

pip3 install rsbcli

#### Windows

pip install rsbcli 

### How to use

#### Windows
Open powershell and type rcb(We messed up here) image

Then type rcb open image

#### Linux/Mac
Open terminal and type rcb

Then type rcb open

### Softwares used

Visual Studio Code - https://github.com/Microsoft/vscode

Python 3.9.1

Special Thanks to https://github.com/arghyagod-coder